@@ -116,25 +116,4 @@ impl IOHandle {
     }
 }
 
-#[derive(Debug, Clone, PartialEq, Eq, PartialOrd, Ord)]
-pub struct IOError {
-    msg: String,
-}
-
-impl Error for IOError {
-    fn new<S: AsRef<str>>(msg: S) -> Self {
-        IOError {
-            msg: msg.as_ref().to_string(),
-        }
-    }
-
-    fn from<E: Error>(err: &E) -> Self {
-        IOError {
-            msg: err.to_string(),
-        }
-    }
-
-    fn to_string(&self) -> String {
-        self.msg.clone()
-    }
-}
+pub type IOError = Error;
