@@ -1,34 +1,13 @@
 use super::*;
 
-struct TestError {
-    msg: String,
-}
-
-impl Error for TestError {
-    fn new<S: AsRef<str>>(msg: S) -> Self {
-        TestError {
-            msg: msg.as_ref().to_string(),
-        }
-    }
-
-    fn from<E: Error>(err: &E) -> Self {
-        TestError {
-            msg: err.to_string(),
-        }
-    }
-
-    fn to_string(&self) -> String {
-        self.msg.clone()
-    }
-}
+pub type TestError = Error;
 
 #[test]
 fn test_err() {
     let err = TestError::new("test error");
-    let err_box: err::ErrorBox<TestError> = err::ErrorBox::from(&err);
 
     assert_eq!(err.to_string(), "test error");
-    assert_eq!(err_box.to_string(), "test error");
+    assert_eq!(format!("{}", err), "test error");
 }
 
 #[test]
